﻿using System;
using BlazorApp.Models;
using Microsoft.AspNetCore.Components;
using Microsoft.JSInterop;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using BlazorApp.Services;
using Blazorise.DataGrid;
using Microsoft.AspNetCore.Components.Web;
using Microsoft.Extensions.Localization;
using System.Collections.Generic;
using BlazorApp.Pages;

namespace BlazorApp.Components
{
    public partial class InventoryComp
    {

        [Parameter]
        public int InventorySize { get; set; }

        public Item CurrentDragItem { get; set; }

        public int CurrentDragIndex { get; set; }

        public int CurrentDragNbItem { get; set; }

        [Inject]
        public IDataService DataService { get; set; }

        [Inject]
        public IStringLocalizer<List> Localizer { get; set; }

        [Parameter]
        public List<Item> Items { get; set; }

        public List<Item> InventoryItems { get; set; }

        public ObservableCollection<CraftingAction> Actions { get; set; }

        [Inject]
        internal IJSRuntime JavaScriptRuntime { get; set; }

        private int totalItem;

        public bool IsSorted { get; set; }

        private int PageSize { get; set; }

        private int CurrentPage { get; set; }

        private string Recherche { get; set; }


        public InventoryComp()
        {
            Actions = new ObservableCollection<CraftingAction>();

            Actions.CollectionChanged += OnActionsCollectionChanged;

            

        }

        protected override void OnInitialized()
        {
            this.InventoryItems = new List<Item>(new Item[InventorySize]);
        }



        private void OnActionsCollectionChanged(object? sender, NotifyCollectionChangedEventArgs e)
        {
            JavaScriptRuntime.InvokeVoidAsync("Crafting.AddActions", e.NewItems);
        }

        private async Task OnReadData(DataGridReadDataEventArgs<Item> e)
        {
            if (e.CancellationToken.IsCancellationRequested)
            {
                return;
            }

            CurrentPage = e.Page;
            PageSize = e.PageSize;

            if (!e.CancellationToken.IsCancellationRequested && !IsSorted && string.IsNullOrWhiteSpace(Recherche))
            {
                Items = await DataService.List(e.Page, e.PageSize);
                totalItem = await DataService.Count();

            }
            else if (!string.IsNullOrWhiteSpace(Recherche))
            {
                (Items, totalItem) = await DataService.SearchList(CurrentPage, PageSize, Recherche);

            }
            else
            {
                Items = await DataService.SortedList(CurrentPage, PageSize);
            }
        }

        private async Task SortByName()
        {
            if (!IsSorted)
            {
                IsSorted = true;
                Items = await DataService.SortedList(CurrentPage, PageSize);
            }
        }

        private async void OnInput(Microsoft.AspNetCore.Components.ChangeEventArgs args)
        {
            Recherche = (string)args.Value;

            if (string.IsNullOrWhiteSpace(Recherche))
            {
                if (!IsSorted)
                {
                    Items = await DataService.List(CurrentPage, PageSize);
                }
                else
                {
                    Items = await DataService.SortedList(CurrentPage, PageSize);
                }
                totalItem = await DataService.Count();
            }
            else
            {
                (Items, totalItem) = await DataService.SearchList(CurrentPage, PageSize, Recherche);
            }
            StateHasChanged();
        }

    }
}